@@ -1,3 +1,5 @@
+import sys
+
 from .common import *
 
 from av.subtitles.subtitle import *
@@ -44,7 +46,8 @@ class TestSubtitle(TestCase):
 
         bms = sub.planes
         self.assertEqual(len(bms), 1)
-        self.assertEqual(len(buffer(bms[0])), 4800)
+        if hasattr(__builtins__, 'buffer'):
+            self.assertEqual(len(buffer(bms[0])), 4800)
         if hasattr(__builtins__, 'memoryview'):
             self.assertEqual(len(memoryview(bms[0])), 4800)
 
